==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/component/signalprovisionsandrequirements/impl/RequiredSignalSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.RequiredSignalBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.RequiredSignalBodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredSignal;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredSignalSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.RequiredExecutablePropertySetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.SignalInvocationSet;
import io.ciera.tool.sql.ooaofooa.invocation.impl.SignalInvocationSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.SignalEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SignalEventSetImpl;

import java.util.Arrays;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;


public class RequiredSignalSetImpl extends InstanceSet<RequiredSignalSet,RequiredSignal> implements RequiredSignalSet {

    // attributes
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setAction_Semantics( m_Action_Semantics );
    }
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setDialect( m_Dialect );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setId( ref_Id );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setDescrip( m_Descrip );
    }
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setAction_Semantics_internal( m_Action_Semantics_internal );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setName( m_Name );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setSuc_Pars( m_Suc_Pars );
    }


    // selections
    @Override
    public RequiredExecutablePropertySet R4502_is_a_RequiredExecutableProperty() throws XtumlException {
        RequiredExecutablePropertySet requiredexecutablepropertyset = new RequiredExecutablePropertySetImpl();
        for ( RequiredSignal requiredsignal : this ) requiredexecutablepropertyset.add( requiredsignal.R4502_is_a_RequiredExecutableProperty() );
        return requiredexecutablepropertyset;
    }
    @Override
    public SignalEventSet R529_SignalEvent() throws XtumlException {
        SignalEventSet signaleventset = new SignalEventSetImpl();
        for ( RequiredSignal requiredsignal : this ) signaleventset.add( requiredsignal.R529_SignalEvent() );
        return signaleventset;
    }
    @Override
    public SignalInvocationSet R660_SignalInvocation() throws XtumlException {
        SignalInvocationSet signalinvocationset = new SignalInvocationSetImpl();
        for ( RequiredSignal requiredsignal : this ) signalinvocationset.addAll( requiredsignal.R660_SignalInvocation() );
        return signalinvocationset;
    }
    @Override
    public RequiredSignalBodySet R684_RequiredSignalBody() throws XtumlException {
        RequiredSignalBodySet requiredsignalbodyset = new RequiredSignalBodySetImpl();
        for ( RequiredSignal requiredsignal : this ) requiredsignalbodyset.add( requiredsignal.R684_RequiredSignalBody() );
        return requiredsignalbodyset;
    }


    @Override
    public RequiredSignal nullElement() {
        return RequiredSignalImpl.EMPTY_REQUIREDSIGNAL;
    }

    @Override
    public RequiredSignalSet emptySet() {
      return new RequiredSignalSetImpl();
    }

    @Override
    public RequiredSignalSet value() {
        return this;
    }

    @Override
    public List<RequiredSignal> elements() {
        RequiredSignal[] elements = toArray(new RequiredSignal[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/component/signalprovisionsandrequirements/impl/RequiredSignalSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.RequiredSignalBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.RequiredSignalBodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredSignal;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredSignalSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.RequiredExecutablePropertySetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.SignalInvocationSet;
import io.ciera.tool.sql.ooaofooa.invocation.impl.SignalInvocationSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.SignalEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SignalEventSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;


public class RequiredSignalSetImpl extends InstanceSet<RequiredSignalSet,RequiredSignal> implements RequiredSignalSet {

    public RequiredSignalSetImpl() {
    }

    public RequiredSignalSetImpl(Comparator<? super RequiredSignal> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setDialect( m_Dialect );
    }
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setAction_Semantics_internal( m_Action_Semantics_internal );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setName( m_Name );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setSuc_Pars( m_Suc_Pars );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setId( ref_Id );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setDescrip( m_Descrip );
    }
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( RequiredSignal requiredsignal : this ) requiredsignal.setAction_Semantics( m_Action_Semantics );
    }


    // selections
    @Override
    public RequiredExecutablePropertySet R4502_is_a_RequiredExecutableProperty() throws XtumlException {
        RequiredExecutablePropertySet requiredexecutablepropertyset = new RequiredExecutablePropertySetImpl();
        for ( RequiredSignal requiredsignal : this ) requiredexecutablepropertyset.add( requiredsignal.R4502_is_a_RequiredExecutableProperty() );
        return requiredexecutablepropertyset;
    }
    @Override
    public SignalEventSet R529_SignalEvent() throws XtumlException {
        SignalEventSet signaleventset = new SignalEventSetImpl();
        for ( RequiredSignal requiredsignal : this ) signaleventset.add( requiredsignal.R529_SignalEvent() );
        return signaleventset;
    }
    @Override
    public SignalInvocationSet R660_SignalInvocation() throws XtumlException {
        SignalInvocationSet signalinvocationset = new SignalInvocationSetImpl();
        for ( RequiredSignal requiredsignal : this ) signalinvocationset.addAll( requiredsignal.R660_SignalInvocation() );
        return signalinvocationset;
    }
    @Override
    public RequiredSignalBodySet R684_RequiredSignalBody() throws XtumlException {
        RequiredSignalBodySet requiredsignalbodyset = new RequiredSignalBodySetImpl();
        for ( RequiredSignal requiredsignal : this ) requiredsignalbodyset.add( requiredsignal.R684_RequiredSignalBody() );
        return requiredsignalbodyset;
    }


    @Override
    public RequiredSignal nullElement() {
        return RequiredSignalImpl.EMPTY_REQUIREDSIGNAL;
    }

    @Override
    public RequiredSignalSet emptySet() {
      return new RequiredSignalSetImpl();
    }

    @Override
    public RequiredSignalSet emptySet(Comparator<? super RequiredSignal> comp) {
      return new RequiredSignalSetImpl(comp);
    }

    @Override
    public RequiredSignalSet value() {
        return this;
    }

    @Override
    public List<RequiredSignal> elements() {
        RequiredSignal[] elements = toArray(new RequiredSignal[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
